package com.inspect.metadata.patrolpointmnt.service;

import com.inspect.metadata.patrolpointmnt.domain.BasedataPatrolType;

import java.util.List;

public interface IBasedataPatrolTypeService {
    BasedataPatrolType selectBasedataPatrolTypeByPatrolTypeId(Long patrolPointId);

    List<BasedataPatrolType> selectBasedataPatrolTypeList(BasedataPatrolType patrolType);

    int insertBasedataPatrolType(BasedataPatrolType patrolType);

    int updateBasedataPatrolType(BasedataPatrolType patrolType);

    int deleteBasedataPatrolTypeByPatrolTypeIds(Long[] patrolPointIds);

    int deleteBasedataPatrolTypeByPatrolTypeId(Long patrolPointId);
}
